@@ -1,22 +1,7 @@
+# Copyright © Michal Čihař <michal@weblate.org>
 #
-# Copyright © 2012–2022 Michal Čihař <michal@cihar.com>
-#
-# This file is part of Weblate translation-finder
-# <https://github.com/WeblateOrg/translation-finder>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <https://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 """Filesystem finder for translations."""
 
 import re
@@ -132,5 +117,5 @@ class Finder:
             if fileglob.fullmatch(filename):
                 yield path
 
-    def open(self, path, *args, **kwargs):
+    def open(self, path, *args, **kwargs):  # noqa: A003
         return self.absolutes[path.as_posix()].open(*args, **kwargs)
