@@ -1,22 +1,6 @@
+# Copyright © Michal Čihař <michal@weblate.org>
 #
-# Copyright © 2012–2022 Michal Čihař <michal@cihar.com>
-#
-# This file is part of Weblate translation-finder
-# <https://github.com/WeblateOrg/translation-finder>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <https://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 import os.path
 from io import StringIO
@@ -79,6 +63,11 @@ class APITest(DiscoveryTestCase):
                     "filemask": "json/i18next-*.json",
                     "template": "json/i18next-en.json",
                 },
+                {
+                    "file_format": "i18nextv4",
+                    "filemask": "json/i18nextv4-*.json",
+                    "template": "json/i18nextv4-en.json",
+                },
                 {
                     "file_format": "json-nested",
                     "filemask": "json/nested-*.json",
@@ -179,6 +168,11 @@ class APITest(DiscoveryTestCase):
                     "filemask": "xliff/*.xlf",
                     "template": "xliff/en.xlf",
                 },
+                {
+                    "file_format": "gotext-json",
+                    "filemask": "json/gotext-*.json",
+                    "template": "json/gotext-en.json",
+                },
             ],
         )
 
